@@ -3,13 +3,13 @@
 
 """ 
 	Simple Function graph Plotter
-	© Thomas Führinger, Sam Tygier 2005-2006
+	© Thomas Führinger, Sam Tygier 2005-2007
 	http://lybniz2.sourceforge.net/
 	
-	Version 1.3
+	Version 1.3.2
 	Requires PyGtk 2.6	
 	Released under the terms of the revised BSD license
-	Modified: 2006-11-01
+	Modified: 2007-12-14
 """
 
 from __future__ import division
@@ -18,7 +18,7 @@ import sys
 import math
 from math import *
 
-app_version = 1.3
+app_version = "1.3.2"
 
 try:
 	import gnome
@@ -513,7 +513,7 @@ def evaluate(widget, event=None):
 			try:
 				x = float(dlg_win.x_entry.get_text())
 				safe_dict['x']=x
-				e[1].set_text(str(eval(e[0],{"__builtins__":{}},safe_dict)))
+				e[1].set_text(str(eval(e[0].replace("^","**"),{"__builtins__":{}},safe_dict)))
 			except:
 				if len(e[0]) > 0:
 					e[1].set_text("Error: %s" % sys.exc_value)
@@ -650,7 +650,7 @@ def save(widget, event=None):
 	if response == gtk.RESPONSE_OK:
 		x, y, w, h = graph.drawing_area.get_allocation()
 		pix_buffer = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, w, h)
-		pix_buffer.get_from_drawable(graph.PixMap, graph.PixMap.get_colormap(), 0, 0, 0, 0, w, h)
+		pix_buffer.get_from_drawable(graph.pix_map, graph.pix_map.get_colormap(), 0, 0, 0, 0, w, h)
 		pix_buffer.save(file_dialog.get_filename(), "png")
 	file_dialog.destroy()
 
